@@ -38,7 +38,7 @@ that offers links between `RemoteObject` instances, `Link`.
 
 """
 
-from datetime import datetime
+from datetime import datetime, tzinfo, timedelta
 import logging
 import time
 import urlparse
@@ -309,7 +309,23 @@ class Dict(List):
         return dict((k, self.fld.encode(v)) for k, v in value.iteritems())
 
 
-class Object(Field):
+class AcceptsStringCls(object):
+    """Mixin for fields with a ``cls`` attribute that can either be a
+    ``DataObject`` subclass or a string name of a ``DataObject`` subclass (to
+    allow forward references)."""
+
+    def get_cls(self):
+        cls = self.__dict__['cls']
+        if not callable(cls):
+            cls = remoteobjects.dataobject.find_by_name(cls)
+        return cls
+
+    def set_cls(self, cls):
+        self.__dict__['cls'] = cls
+
+    cls = property(get_cls, set_cls)
+
+class Object(AcceptsStringCls, Field):
 
     """A field representing a nested `DataObject`."""
 
@@ -330,17 +346,6 @@ class Object(Field):
         super(Object, self).__init__(**kwargs)
         self.cls = cls
 
-    def get_cls(self):
-        cls = self.__dict__['cls']
-        if not callable(cls):
-            cls = remoteobjects.dataobject.find_by_name(cls)
-        return cls
-
-    def set_cls(self, cls):
-        self.__dict__['cls'] = cls
-
-    cls = property(get_cls, set_cls)
-
     def decode(self, value):
         """Decodes the dictionary value into an instance of the `DataObject`
         class the field references."""
@@ -356,11 +361,26 @@ class Object(Field):
         return value.to_dict()
 
 
+class UTC(tzinfo):
+    """UTC"""
+    ZERO = timedelta(0)
+
+    def utcoffset(self, dt):
+        return UTC.ZERO
+
+    def tzname(self, dt):
+        return "UTC"
+
+    def dst(self, dt):
+        return UTC.ZERO
+
+
 class Datetime(Field):
 
     """A field representing a timestamp."""
 
     dateformat = "%Y-%m-%dT%H:%M:%SZ"
+    utc = UTC()
 
     def __init__(self, dateformat=None, **kwargs):
         super(Datetime, self).__init__(**kwargs)
@@ -372,15 +392,15 @@ class Datetime(Field):
         `datetime` instance).
 
         Timestamp strings should be of the format ``YYYY-MM-DDTHH:MM:SSZ``.
-        The resulting `datetime` will have no time zone.
-
+        The resulting `datetime` will have UTC tzinfo.
         """
         if value is None:
             if callable(self.default):
                 return self.default()
             return self.default
         try:
-            return datetime(*(time.strptime(value, self.dateformat))[0:6])
+            return datetime(*(time.strptime(value, self.dateformat))[0:6],
+                    tzinfo=Datetime.utc)
         except (TypeError, ValueError):
             raise TypeError('Value to decode %r is not a valid date time stamp' % (value,))
 
@@ -395,11 +415,11 @@ class Datetime(Field):
         if not isinstance(value, datetime):
             raise TypeError('Value to encode %r is not a datetime' % (value,))
         if value.tzinfo is not None:
-            raise TypeError("Value to encode %r is a datetime, but it has timezone information and we don't want to deal with timezone information" % (value,))
+            value = value.astimezone(Datetime.utc)
         return value.replace(microsecond=0).strftime(self.dateformat)
 
 
-class Link(Property):
+class Link(AcceptsStringCls, Property):
 
     """A `RemoteObject` property representing a link from one `RemoteObject`
     instance to another.
