@@ -27,7 +27,7 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
-from datetime import datetime
+from datetime import datetime, timedelta, tzinfo
 import logging
 import pickle
 import sys
@@ -61,6 +61,17 @@ class TestDataObjects(unittest.TestCase):
         self.assertEquals(BasicMost.__name__, 'BasicMost',
             "metaclass magic didn't break our class's name")
 
+        bm = BasicMost(name='fred', value=2)
+        bm.api_data = {"name": "fred", "value": 2}
+        bm_dict = bm.to_dict()
+        self.assertEquals({ 'name': 'fred', 'value': 2 }, bm_dict, 'First go-round has proper contents')
+        bm.name = 'tom'
+        bm_dict = bm.to_dict()
+        self.assertEquals({ 'name': 'tom', 'value': 2 }, bm_dict, 'Setting name to another string works')
+        bm.name = None
+        bm_dict = bm.to_dict()
+        self.assertEquals({ 'value': 2 }, bm_dict, 'Setting name to None works, and name is omitted in the dict')
+
     def test_descriptorwise(self):
 
         class BasicMost(self.cls):
@@ -89,7 +100,8 @@ class TestDataObjects(unittest.TestCase):
         self.assert_(w, 'from_dict returned something True')
         self.assertEquals(w.name, 'foo', 'Typething got the right name')
         self.assertEquals(w.value, 4, 'Typething got the right value')
-        self.assertEquals(w.when, datetime(2008, 12, 31, 4, 0, 1, tzinfo=None),
+        self.assertEquals(w.when, datetime(2008, 12, 31, 4, 0, 1,
+            tzinfo=fields.Datetime.utc),
             'Typething got something like the right when')
 
         w = WithTypes(name='hi', value=99, when=datetime(2009, 2, 3, 10, 44, 0, tzinfo=None)).to_dict()
@@ -445,6 +457,16 @@ class TestDataObjects(unittest.TestCase):
         # Links don't serialize... for now anyways.
         self.assertEquals(x.to_dict(), {})
 
+    def test_forwards_link(self):
+        class Foo(dataobject.DataObject):
+            link = fields.Link('Bar')
+
+        class Bar(dataobject.DataObject):
+            thing = fields.Field()
+
+        # The string class name should be converted to the class
+        self.assertEquals(Foo.__dict__["link"].cls, Bar)
+
     def test_field_datetime(self):
 
         class Timely(dataobject.DataObject):
@@ -456,15 +478,40 @@ class TestDataObjects(unittest.TestCase):
 
         self.assert_(isinstance(t, Timely), 'Datetime class decoded properly')
         self.assert_(isinstance(t.when, datetime), 'Datetime data decoded into a datetime')
-        when = datetime(year=2008, month=12, day=31, hour=4, minute=0, second=1)
+        when = datetime(year=2008, month=12, day=31, hour=4, minute=0, second=1,
+                tzinfo=fields.Datetime.utc)
         self.assertEquals(t.when, when, 'Datetime data decoded into the expected datetime')
-        self.assert_(t.when.tzinfo is None, 'Datetime data decoded with no timezone info')
+        self.assert_(t.when.tzinfo is fields.Datetime.utc, 
+                'Datetime data decoded with utc timezone info')
 
         when = datetime(year=2010, month=2, day=11, hour=4, minute=37, second=44)
         t_data = Timely(when=when).to_dict()
         self.assert_(isinstance(t_data, dict), 'Datetime dict encoded properly')
         self.assertEquals(t_data['when'], '2010-02-11T04:37:44Z', 'Datetime dict encoded with expected timestamp')
 
+        when = datetime(year=2010, month=2, day=11, hour=4, minute=37,
+                second=44, tzinfo=fields.Datetime.utc)
+        t_data = Timely(when=when).to_dict()
+        self.assert_(isinstance(t_data, dict), 'Datetime dict with UTC tzinfo encoded properly')
+        self.assertEquals(t_data['when'], '2010-02-11T04:37:44Z', 'Datetime dict encoded with expected timestamp')
+
+        class EST(tzinfo):
+
+            def utcoffset(self, dt):
+                return timedelta(hours=-5)
+
+            def tzname(self, dt):
+                return "UTC"
+
+            def dst(self, dt):
+                return timedelta(0)
+
+        when = datetime(year=2010, month=2, day=10, hour=23, minute=37,
+                second=44, tzinfo=EST())
+        t_data = Timely(when=when).to_dict()
+        self.assert_(isinstance(t_data, dict), 'Datetime dict with non-UTC tzinfo encoded properly')
+        self.assertEquals(t_data['when'], '2010-02-11T04:37:44Z', 'Datetime dict encoded with expected timestamp')
+
         t = Timely.from_dict({
             'when': None,
         })
